import requests
from bs4 import BeautifulSoup

__author__ = "Engine Bai"
url = "http://trust-api-trust-staging.192.168.99.100.nip.io/api/v5/api-docs/#/"

req = requests.get(url)
#html = BeautifulSoup(req.text, "html.parser")
#content_tag = html.find("div", attrs={"class": "topbar",
#                                      "data-source": "post_page"})
print(req.text)


import os
import time
import subprocess
import requests 
import json
#from   .create_load_test_file import *
import logging

def get_url_delete(URL,data):

    try:
        if URL[len(URL)-1] == '/':
            A = ''
        else:
            A = '/'
    
        URL = URL + A
        NAME = data.keys()
        VALUE = data.values()
        URL_GET = "?"
    
        for n,v in zip(NAME,VALUE):
            if n != 'id':
                URL_GET = URL_GET + str(n) + "=" + str(v) + '&'
        URL_GET = URL +URL_GET[0:len(URL_GET)-1]    
      
        response = requests.get(URL_GET)
        data = response.json()
        data = data['results']
        data = data[0]
        URL_DELETE = URL + str(data['id'])
    except:
        A = "NO EXISTE LOS DATOS"
        URL_DELETE = ""
    return URL_DELETE

def print_logs(NAME,PASS,URL,LOGS):
    if PASS =='OK':
        COLOR_CODE ='\033[92m'
    elif PASS =='ERROR':
        COLOR_CODE ='\033[91m'
    elif PASS == "HEADER":  COLOR_CODE= '\033[95m'
    elif PASS =="OKBLUE": COLOR_CODE= '\033[94m'
    elif PASS =="OKGREEN": COLOR_CODE= '\033[92m'
    elif PASS =="WARNING": COLOR_CODE= '\033[93m'
    elif PASS =="FAIL": COLOR_CODE= '\033[91m'
    elif PASS =="ENDC": COLOR_CODE= '\033[0m'
    elif PASS =="BOLD": COLOR_CODE= '\033[1m'
    elif PASS =="UNDERLINE": COLOR_CODE= '\033[4m'

    if len(URL) >= 40:
        URL = URL[0:37] + "..."

    print(COLOR_CODE + "|TYPE_TEST: =%12s | PASS: %8s    | URL: %40s| LOGS :%50s"%(NAME,PASS,URL,LOGS))    

def urlfilter(URL,data):
    if len(data) > 0 or data == None:
        if URL[len(URL)-1] == '/':
            A = ''
        else:
            A = '/'
        URL = URL + A
        NAME = data.keys()
        VALUE = data.values()
        URL_GET = "?"
        for n,v in zip(NAME,VALUE):
            if n != 'id':
                URL_GET = URL_GET + str(n) + "=" + str(v) + '&'
        URL_GET = URL +URL_GET[0:len(URL_GET)-1]    
    else:
        URL_GET = URL
    return URL_GET

class ping():
    def __init__(self,server):
        self.server  = server  # Service address to test
 
    def check(self):
        ip      = self.server
        output, error = subprocess.Popen((['ping', ip, '-c', '3']), stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()

        if len(error) == 0:
            
            PASS     = "OK"
            logs     = "SUCCESS"
            request  = 200
            passTest = True
        else:
            logs          = "Error 404: Fail Ping ("+str(ip)+")"
            request       = 404
            PASS          = "ERROR"
            passTest      = False

        print("PASSTEST PING: ",passTest)

        self.request  = request
        self.passTest = passTest
        self.logs     = logs
        
        return self.request,self.passTest,self.logs

        

class apirest():
    def __init__(self,URL,data=None,token=None,request_data=None):
        self.url          = URL
        self.data         = data
        self.token        = token      
        self.request_data = request_data
         
    def get(self):
        url          = self.url 
        data         = self.data
        data_request = {"A":"A"}
        token        = self.token
        request_data = self.request_data


        if token != None:
            head={'Authorization': token}
            response = requests.get(url, headers=head)
        else:
            response  = requests.get(url)
        code      = response.status_code    
        try:
            response = response.json()
            response = response.encode('ascii','ignore')
        except:
          print("ERROR")       
        print(response)         
        
        print("COOOODE:     ",code, url)
        print()
        print()
        print(request_data)
        print()
        print()

        if code == 200 or code == 202 or code == 203:
            CONTENT  = True   
            logs     = "OK SUCCESS"
            PASS     = "OK"
            passTest = True

            if request_data!= None:
                if request_data == response:
                    passTest= True
                else:
                    passTest= False
                    logs  = "ERROR GET: DATA request_data == request NOT IS IQUAL"
        else:
            CONTENT = False  
            code = 404  
            logs = "WARNING: Data not found ("+str(data)+")"
            PASS = "WARNING"
            passTest = False
        request = code  
            #// Check if exist the data filter
            


        data_request["request"]   = request  
        data_request["passTest"]  = passTest  
        data_request["logs"]      = logs
        

        self.request  = request
        self.passTest = passTest
        self.logs     = logs
        return  self.request,self.passTest,self.logs

    def post(self):
        url          = self.url 
        data2        = self.data
        token        = self.token
        request_data = self.request_data

        if True==True:
            # 1 Step: DELETE OLD DATA.
            # // 1 Step: DELETE OLD DATA.
            # 2 Step: POST DATA
            if token != None:
                head={'Authorization': token}
                response = requests.post(url,data=data2,headers=head)
            else:
                response  = requests.post(url,data=data2)           
            code     = int(response.status_code)

            print("PRINT CODE POST: ", code)

            try:
                response = response.json()
                response = response.encode('ascii','ignore')
            except:
                print("ERROR")

            # // 2 Step: POST DATA
            # Check if exist the data filter
            resp = response
            # resp      = response['results']
            if code ==  200 or code == 201:
                CONTENT = True   
                logs  = "SUCCESS"
                PASS     = "OK"
                passTest= True
                if request_data!= None:
                    if request_data == response and request_data != None:
                        passTest= True
                    else:
                        passTest= False
                        logs  = "ERROR POST:  DATA request_data == request NOT IS IQUAL"
            else:
                print("CLOSE ")
                passTest= False
                CONTENT = False  
                code = 404  
                logs = "WARNING: Data not found API ADRESS ("+str(url) +" "+ str(data2)+")"
                PASS = "WARNING"

            #// Check if exist the data filter
           
      #  else:
      #      code = 404
      #      logs = "FATAL ERROR APIsPost, CHECK THE >"+ str(url)
      #      request = 405
      #      passTest = False
      #  
        request = code
     
        self.request  = request
        self.passTest = passTest
        self.logs     = logs
        return  self.request,self.passTest,self.logs


    def put(self):
        url          = self.url 
        data         = self.data
        data_request = {"A":"A"}
        token        = self.token

        if token != None:
            head={'Authorization': token}
            response = requests.put(url,data=data,headers=head)
        else:
            response  = requests.put(url, data=data)

        code      = response.status_code

        print("COOOODE PUT:     ",code, url)

        if code == 200 or code == 202 or code == 203:
            CONTENT = True   
            logs  = "OK SUCCESS"
            PASS     = "OK"
            passTest= True
        else:
            CONTENT = False  
            code = 404  
            logs = "WARNING: Data not found ("+str(data)+")"
            PASS = "WARNING"
            passTest = False
         
        request = code  
        data_request["request"]   = request  
        data_request["passTest"]  = passTest  
        data_request["logs"]      = logs
        
        self.request  = request
        self.passTest = passTest
        self.logs     = logs

        return  self.request,self.passTest,self.logs

# D = apirest("http://localhost:8000/api/v1/project/",{"project": "Trust"}).get()

class smktest:
    class ping():
        name   = ''
        school = ''
        def __init__(self,server):
            self.server  = server  # Service address to test
        def check(self):
            ip      = self.server
            output, error = subprocess.Popen((['ping', ip, '-c', '2']), stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
            if len(output) > 0:
                CODE = 200
                PASS = "OK"
                logs = "Test Ping Success CODE 200"
            else:
                logs = "Error Ping Test CODE 404"
                CODE = 404
                PASS = "ERROR"

            self.CODE = CODE
            return self

    class perform(): 
        def __init__(self,TYPE_TEST,URL,data=None,token=None,request_data=None):
            
            self.TYPE_TEST = TYPE_TEST  # Service address to test
            self.data      = data
            self.URL       = URL
            self.request   = 0
            self.token     = token
            self.request_data = request_data


            CODE = 0
            passTest = True
            if TYPE_TEST == "ping":
                DATA     = ping(URL).check()
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  PING TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. Service Address Error.']    

                assert passTest == True,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list)) 
                           
            elif TYPE_TEST == "ping_fail":
                DATA     = ping(URL).check()
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  PING TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. Service Address Error.']    

                assert passTest == False,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list)) 
                           

 
            elif TYPE_TEST == "api_get":
                
                DATA = apirest(URL,data,token=token,request_data=request_data).get()

                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  API GET  TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. API Address Error.',]    


                assert  passTest == True,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))      

            elif TYPE_TEST == "api_get_fail":
                DATA = apirest(URL,data).get()
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  API GET  TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. API Address Error.',]    
                assert  passTest == False,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))      

            
            elif TYPE_TEST == "api_post":

                DATA = apirest(URL,data=data,token=token,request_data=request_data).post()
                print(DATA)
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  API POST  TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. API Address Error.','3. Incorrect data structure']   
                
                print(request)

                assert  passTest == True,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))     

            elif TYPE_TEST == "api_post_fail":
                DATA = apirest(URL,data).post()
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  API POST  TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. API Address Error.','3. Incorrect data structure']        

                assert  passTest == False,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))        

            elif TYPE_TEST == "api_put":

                DATA = apirest(URL,data=data,token=token).put()
                print(DATA)
                request  = DATA[0]
                passTest = DATA[1]
                logs     = DATA[2]

                test_metadata = "- TYPE:  API POST  TEST | CHECK THE SERVER ADRESS: ("+str(URL)+")"
                failure_list = ['','ERROR CASES:','','1. Inactive Service.','2. API Address Error.','3. Incorrect data structure']   
                
                assert  passTest == True,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))   
              #  return request
            else:
                test_metadata = "- TYPE:  VERB ACCION NO EXIST: ("+str(URL)+") + >>>"+str(TYPE_TEST)+""
                failure_list = ['','ERROR CASES:','','1. ERROR INSERT CASE']   
                passTest = False 
                assert  passTest == True,"\n---- SMOKE TEST ERROR ----\n%s\n----FAILURE-LIST----\n%s"%(test_metadata,'\n'.join(failure_list))                                       


    #class load(): 
    #    def __init__(self,data_load):
    #        self.data_load = data_load
    #        start_load_test(data_load)





import requests
import json
import os
import csv

def crate_file_load_test(data_load):

    file = open("locust_test.py", "w") 
    file.write("from   locust import HttpLocust, TaskSet, between, task, seq_task") 
    file.write("\n")
    file.write("from   locust.events import request_failure") 
    file.write("\n")
    file.write("import requests ") 
    file.write("\n")
    file.write("import json") 
    file.write("\n")
    file.write("import random") 
    file.write("\n")
    file.write("\n")
    file.write("\n")
    
    
    print("GENERATE FILE: locust_test.py")
    
    file.write("class WebsiteTasks(TaskSet):") 
    file.write("\n")
    count = 0
    for i in data_load:
        count  = count + 1
        type_s = i["type"]
        url    = i["URL"]
        data_s = i["DATA"]
    
    
        if type_s ==  "get":
            
            file.write("    @task(1)")  
    
            file.write("\n")
            file.write("    def get_data_"+str(count)+"(self):")
            file.write("\n")
            file.write('        self.client.get("'+str(url)+'") ')  
            file.write("\n")
    
        elif type_s == "post":
            file.write("    @task(1)")  
            file.write("\n")
            file.write("    def post_data_"+str(count)+"(self):")
            file.write("\n")
            file.write('        self.client.post("'+str(url)+'",'+str(data_s)+') ') 
            
    
    
        file.write("\n")
        file.write("\n")
    
    file.write("\n")
    file.write("\n")
    file.write("\n")    
    file.write("\n")
    file.write("\n")
    file.write("class WebsiteUser(HttpLocust):")
    file.write("\n")
    file.write("    task_set  = WebsiteTasks")
    file.write("\n")
    file.write("    min_wait  = 5000")
    file.write("\n")
    file.write("    max_wait  = 15000")
    file.write("\n")
    
# locust  -f locust_test.py --host http://localhost:8000 --no-web -c 1000 -r 100  --run-time 10s  --step-load --step-clients 400  --step-time 10m --csv=example -t10s
    file.close() 
    

def start_load_test(data_load):

    crate_file_load_test(data_load)
    os.system('locust  -f locust_test.py --host http://localhost:8000 --no-web -c 1000 -r 100  --run-time 10s  --step-load --step-clients 200  --step-time 10m --csv=example -t10s')
    
    with open('example_failures.csv') as csv_file:
        csv_reader = csv.reader(csv_file, delimiter=',')
        line_count = 0
        ROWs = []
        for row in csv_reader:
            if line_count == 0:
                print(f'Column names are {", ".join(row)}')
                line_count += 1
            else:
                print(f'\t{row[0]} works in the {row[1]} department, and was born in {row[2]}.')
                line_count += 1
    
            if line_count > 1:
                ROWs.append(row)    
            
        print(f'Processed {line_count} lines.')
        
        try:
            assert line_count == 1     
        except AssertionError as e:
            print("---   LOAD TEST ERROR:   ---- ")
            print()
            print(ROWs)
            print()
            print('--- --- --- --- --- --- ')
            e.args += ('some other', 'important', 'information', 42)
            raise    


from setuptools import setup, find_packages
from distutils.core import setup

with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()


setup(
  name = 'smktest',
  packages = ['smktest'], # this must be the same as the name above
  version = '0.1.1',
  description = 'This package offers a series of tests to create the correct Smoke Test of an application before uploading changes to production.',
  author = 'Cecilio Cannavacciuolo Diaz',
  author_email = 'cecilio.cannav@gmail.com',
  url = 'https://github.com/cecilio-cannav/smktest.git', # use the URL to the github repo
  license='MIT',
  keywords = ['smoketest', 'testing', 'python', 'smart',],
  python_requires='>=3',
)

#setup(name='smktest',
#      version='0.1',
#      description='Easy way to make markdown code for tables',
#      url='https://github.com/cecilio-cannav/smktest.git',
#      author='cecilio cannavacciuolo diaz',
#      author_email='cecilio.cannav@gmail.com',
#      license='MIT',
#      packages=['smktest'],
#      )


install_requires = [
    'subprocess',
    'requests',
    'pytest',
    'pyhttptest',
]




from   locust import HttpLocust, TaskSet, between, task, seq_task
from   locust.events import request_failure
import requests 
import json
import random


class WebsiteTasks(TaskSet):
    @task(1)
    def get_data_1(self):
        self.client.get("http://localhost:8000/api/v1/projectsss/") 


    @task(1)
    def get_data_2(self):
        self.client.get("http://localhost:8000/api/v1/testing/") 


    @task(1)
    def post_data_3(self):
        self.client.post("http://localhost:8000/api/v1/testing/",{'name': 'LoadTest', 'test_type': 'POST'}) 






class WebsiteUser(HttpLocust):
    task_set  = WebsiteTasks
    min_wait  = 5000
    max_wait  = 15000
